California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 019 - ACA 11 (RESOLUTION CHAPTER 31), MULLIN. THE HOME PROTECTION FOR SENIORS, SEVERELY DISABLED, FAMILIES, AND VICTIMS OF WILDFIRE OR NATURAL DISASTERS ACT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1429714 | YES ON 19: COALITION OF FIREFIGHTERS, REALTORS, SENIORS, DISABLED HOMEOWNERS, AND WILDFIRE VICTIMS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400190 | YES ON 19: TAX SAVINGS AND HOUSING RELIEF FOR SENIORS, SEVERELY DISABLED, AND WILDFIRE VICTIMS, SPONSORED BY CALIFORNIA ASSOCIATION OF REALTORS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427752 | STOP THE TAX HIKES, NO ON 15 AND 19, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1431854 | RODRIGUEZ BALLOT MEASURE COMMITTEE; COMMITTEE FOR AN EQUITABLE LOS ANGELES, YES ON 16 & 19, COUNCILWOMAN MONICA | SUPPORT